Check a package's reverse dependencies in order to identify differences in reverse dependency check results when run alongside your package's development and release versions.
Arguments
- path
file path to the package source directory
- n
integervalue indicating maximum number of subprocesses that can be simultaneously spawned when executing tasks.- output
charactervalue specifying path where the output should be stored.- lib.loc
charactervector with libraries allowed to be used when checking packages, defaults to entire.libPaths().- repos
charactervector of repositories which will be used when generating task graph and later pulling dependencies.- reverse_repos
charactervector of repositories which will be used to pull sources for reverse dependencies. In some cases, for instance using binaries on Linux, we want to use different repositories when pulling sources to check and different when installing dependencies.- restore
logicalindicating whether output directory should be unlinked before running checks. IfFALSE, an attempt will me made to restore previous progress from the sameoutput- ...
Additional arguments passed to
run()
Value
checker() R6 class storing all the details
regarding checks that run. Can be combined with
results and summary() methods to generate results.
Details
Runs classical reverse dependency checks for the given source package. It
first identifies reverse dependencies available in repos. Then, after
installing all required dependencies, runs R CMD check twice for each
package, one time with the release version of the given source package
installed from repos and a second time with the development version
installed from local source. Both R CMD checks are later compared to
identify changes in reverse dependency behaviors.
See also
Other checks:
STATUS,
check_pkgs(),
checker,
new_checker()