Create a task to run R CMD check
Arguments
- build_args
Character vector of arguments to pass to
R CMD build. Pass each argument as a single element of this character vector (do not use spaces to delimit arguments like you would in the shell). For example,build_args = c("--force", "--keep-empty-dirs")is a correct usage andbuild_args = "--force --keep-empty-dirs"is incorrect.- args
Character vector of arguments to pass to
R CMD check. Pass each argument as a single element of this character vector (do not use spaces to delimit arguments like you would in the shell). For example, to skip running of examples and tests, useargs = c("--no-examples", "--no-tests")and notargs = "--no-examples --no-tests". (Note that instead of the--outputoption you should use thecheck_dirargument, because--outputcannot deal with spaces and other special characters on Windows.)- env
A named character vector, extra environment variables to set in the check process.
- ...
Arguments passed on to
task.subclassAdditional subclasses.
See also
Other tasks:
install_task(),
meta_task(),
task()