A description of where packages should be installed. This object provides necessary information to determine where a package should be installed. lib_path method creates default path handlers for given pkg origin while lib_path_x creates an actual object.
Arguments
- x
A
pkg_origin()object used for default dispatch.- ...
Additional values
- .class
An optional subclass, used primarily for dispatch.
See also
Other specs:
pkg_origin()