Skip to contents

Meta tasks are tasks which are not intended to perform computation. They exist simply to provide relationships among computational tasks.

Usage

meta_task(..., .subclass = NULL)

Arguments

...

Objects passed to specified class functions

.subclass

character name of the subclass. It will be appended with "_meta" suffix.

See also