Skip to contents

Generates a plan for running installing a package from source.

Usage

plan_local_install(
  package,
  repos = getOption("repos"),
  remotes_dependencies = TRUE,
  INSTALL_opts = c()
)

Arguments

package

A path to package source.

repos

repository used to identify packages when name is provided.

remotes_dependencies

A vector of length one or a named list. Compatible with as_pkg_dependencies. Used to filter out remotes dependencies.

INSTALL_opts

Options to set while the root package is being installed. Check utils::install.packages for details.