Turns checked results into a list of data.frams, one for each meta root task. Such form makes quick results analysis easier by providing a general overview of identified failures.
See also
Other results:
print.checked_results(),
results()
Turns checked results into a list of data.frams, one for each meta root task. Such form makes quick results analysis easier by providing a general overview of identified failures.
Other results:
print.checked_results(),
results()