run() provides a generic, and is the central interface for executing
checkers. If a path is provided, a new reverse dependency check
plan is generated from the source code path. Otherwise a plan can be
built separately and executed using run().
Usage
run(checker, ..., reporter = reporter_default())Arguments
- checker
characterorcheckerIf acharactervalue is provided, it is first coerced into acheckerusingnew_rev_dep_checker().- ...
Additional arguments passed to
new_rev_dep_checker()- reporter
A reporter to provide progress updates. Will default to the most expressive command-line reporter given your terminal capabilities.