Create task specification list which consists of all the details required to run specific task.
See also
Other tasks:
check_task(),
install_task(),
meta_task()
Create task specification list which consists of all the details required to run specific task.
Other tasks:
check_task(),
install_task(),
meta_task()