Runs classical R CMD check for the given source package. It
first identifies and installs, in parallel, all dependencies required
to check the package. Then, it runs R CMD check for each specified package.
Arguments
- package
A path to either package, directory with packages or name of the package (details)
- n
integervalue indicating maximum number of subprocesses that can be simultaneously spawned when executing tasks.- output
charactervalue specifying path where the output should be stored.- lib.loc
charactervector with libraries allowed to be used when checking packages, defaults to entire.libPaths().- repos
charactervector of repositories which will be used when generating task graph and later pulling dependencies.- restore
logicalindicating whether output directory should be unlinked before running checks. IfFALSE, an attempt will me made to restore previous progress from the sameoutput- ...
Additional arguments passed to
run()
Value
checker() R6 class storing all the details
regarding checks that run. Can be combined with
results and summary() methods to generate results.
See also
Other checks:
STATUS,
check_rev_deps(),
checker,
new_checker()