Create a task to install a package and dependencies
Usage
install_task(
origin,
type = package_install_type(origin),
INSTALL_opts = NULL,
lib = lib_path(origin),
...
)Arguments
- origin
pkg_origin()object.- type
character, indicating the type of package to download and install. Will be
"source"except on Windows and some macOS builds: see the section on ‘Binary packages’ for those.- INSTALL_opts
an optional character vector of additional option(s) to be passed to
R CMD INSTALLfor a source package install. E.g.,c("--html", "--no-multiarch", "--no-test-load")or, for macOS,"--dsym".Can also be a named list of character vectors to be used as additional options, with names the respective package names.
- lib
Any object that can be passed to
lib()to generate a library path.- ...
further arguments to be passed to
download.file,available.packages, or to the functions for binary installs on macOS and Windows (which accept an argument"lock": see the section on ‘Locking’).
See also
Other tasks:
check_task(),
meta_task(),
task()