Meta tasks are tasks which are not intended to perform computation. They exist simply to provide relationships among computational tasks.
See also
Other tasks:
check_task(),
install_task(),
task()
Meta tasks are tasks which are not intended to perform computation. They exist simply to provide relationships among computational tasks.
Other tasks:
check_task(),
install_task(),
task()