Generates a plan for running R CMD check for a specified set of packages.
Usage
plan_local_checks(package, repos = getOption("repos"))Details
package parameter has two different allowed values:
Package - checked looks for a DESCRIPTION file in the provided path, if found treats it like a source package.
If the specified value does not correspond to a source package, the parameter is treated as the name and
reposparameter is used to identify the source.
See also
Other plan:
plan_local_install(),
plan_rev_dep_checks()