Generates a plan for running installing a package from source.
Arguments
- package
A path to package source.
- repos
repository used to identify packages when name is provided.
- remotes_dependencies
A vector of length one or a named list. Compatible with
as_pkg_dependencies. Used to filter out remotes dependencies.- INSTALL_opts
Options to set while the root package is being installed. Check
utils::install.packagesfor details.
See also
Other plan:
plan_local_checks(),
plan_rev_dep_checks()