Skip to contents

Generates a plan for running installing a package from source.

Usage

plan_local_install(package, repos = getOption("repos"))

Arguments

package

A path to package source.

repos

repository used to identify packages when name is provided.